# 🌐 Hurricane-Idalia-2023

paused ⏸️ - [dev notes](https://arash-kamangir.medium.com/%EF%B8%8F-conversations-with-ai-229-9257441b3ac0), [dev notes](https://medium.com/@arash-kamangir/%EF%B8%8F-conversations-with-ai-228-f55a0fdf409a).

--urls--

--footer--